@@ -1,6 +1,6 @@
 package JSON::RPC;
 use strict;
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 1;
 
@@ -28,7 +28,7 @@ JSON::RPC - JSON RPC 2.0 Server Implementation
 
 =head1 DESCRIPTION
 
-JSON::RPC is a set of modules that implment JSON RPC 2.0 protocol.
+JSON::RPC is a set of modules that implement JSON RPC 2.0 protocol.
 
     If you are using old JSON::RPC code (up to 0.96), DO NOT EXPECT
     YOUR CODE TO WORK WITH THIS VERSION. THIS VERSION IS 
@@ -115,7 +115,7 @@ The handler methods will receive the following parameters:
         return $some_structure;
     }
 
-In most cases you will only need the parameters. The exact format of the $params is dependend on the caller -- you will be passed whatever JSON structure that caller used to call your handler.
+In most cases you will only need the parameters. The exact format of the $params is dependent on the caller -- you will be passed whatever JSON structure that caller used to call your handler.
 
 $procedure is an instance of JSON::RPC::Procedure. Use it if you need to figure out more about the procedure.
 
@@ -153,7 +153,7 @@ For example, if you would like to your webapp's "rpc" handler to marshall the JS
 
 =head1 ERRORS
 
-When your handler dies, it is automatically included in the response hash.
+When your handler dies, it is automatically included in the response hash, unless no response was requested (see L</NOTIFICATIONS>).
 
 For example, something like below 
 
@@ -192,6 +192,30 @@ This would result in:
         }
     }
 
+=head1 NOTIFICATIONS
+
+Notifications are defined as procedures without an id.
+Notification handling does not produce a response. When all procedures are notifications no content is returned (if the request is valid).
+To maintain some basic compatibility with relaxed client implementations, JSON::RPC::Dispatch includes responses when procedures do not have a "jsonrpc" field set to "2.0".
+
+Note that no error is returned in response to a notification when the handler dies or when the requested method is not available.
+
+For example, a request structure like this:
+
+    [
+        {"jsonrpc": "2.0", "method": "sum", "params": [1,2,4], "id": "1"},
+        {"jsonrpc": "2.0", "method": "notify_hello", "params": [7]},
+        {"jsonrpc": "2.0", "method": "keep_alive"},
+        {"jsonrpc": "2.0", "method": "get_data", "id": "9"}
+    ]
+
+Would result in a response like
+
+    [
+        {"jsonrpc": "2.0", "result": 7, "id": "1"},
+        {"jsonrpc": "2.0", "result": ["hello", 5], "id": "9"}
+    ]
+
 =head1 BACKWARDS COMPATIBILITY
 
 Eh, not compatible at all. JSON RPC 0.xx was fine, but it predates PSGI, and things are just... different before and after PSGI.
